==> fr-server-7.1.jar: com/fr/web/core/js/jquery.message.js <==
(function(a){a.extend(FR,{Msg:function(){return{verticalOffset:0.77,horizontalOffset:1,repositionOnResize:true,overlayOpacity:0.01,overlayColor:"#FFF",draggable:true,okButton:FR.i18nText("OK"),cancelButton:FR.i18nText("Cancel"),dialogClass:null,style:null,textSpace:FR.i18nText("FR-Widget_Message_Letter_Space")+"px",msgStyle:function(){var b=this.style;var c="blue";a.each(["green","blue"],function(d,e){if(b&&e==b.toLowerCase()){c=b.toLowerCase()}});this.style=c},alert:function(c,b,d){FR.Keys.enable(false);
if(!c){c="Alert"}this._show(c,b,null,"alert",function(e){FR.Keys.enable(true);if(a.isFunction(d)){d(e)}},-1);if(typeof d=="number"&&d>0){setTimeout(function(){FR.Msg._hide()},d)}},confirm:function(c,b,e,d){FR.Keys.enable(false);if(!c){c="Confirm"}this._show(c,b,null,"confirm",function(f){FR.Keys.enable(true);if(e){e(f)}},d?d:-1)},prompt:function(d,b,c,f,e){FR.Keys.enable(false);if(!d){d="Prompt"}this._show(d,b,c,"prompt",function(g){FR.Keys.enable(true);if(f){f(g)}},e?e:-1)},toast:function(e){var d=-300;
if(a.browser.msie&&parseInt(a.browser.version)<8){d=-370}var c=a("body").children("div.toast");if(c.length===0){var f=60;if(a.browser.msie&&parseInt(a.browser.version)<=6){f+=a("body")[0].scrollTop}c=a("<div/>").addClass("toast").css({right:d,top:f}).appendTo("body")}c.text(e);var b=a("body").children("div.toastIcon");if(b.length===0){b=a("<div/>").addClass("toastIcon").css({right:0,top:c.css("top"),"z-index":c.css("z-index")+1}).appendTo("body");new FR.IconButton({width:b.css("width"),height:b.css("height"),imgsrc:"fr_show_toast",renderEl:a("<div/>").appendTo(b),handler:function(){c.animate({right:-4},"slow");
setTimeout(function(){c.animate({right:d},"slow")},5000)}})}b.hide();c.animate({right:-15},"slow");(function(){c.animate({right:d},"slow",function(){b.show();b.fadeOut(5000)})}).defer(5000)},_show:function(w,j,s,d,i,p){this.msgStyle();this._hide();this._overlay("show");a("BODY").append('<div id="popup_container"><div id="popup_header" ><h1 id="popup_title"></h1></div><div id="popup_content"><div id="popup_message"></div></div></div>');if(this.dialogClass){a("#popup_container").addClass(this.dialogClass)
}var l=(a.browser.msie)?"absolute":"fixed";a("#popup_container").css({position:l,zIndex:99999,padding:0,margin:0,top:0,left:0});a("#popup_title").html(w);a("#popup_content").addClass(d);a("#popup_message").text(j);a("#popup_message").html(a("#popup_message").text().replace(/\n/g,"<br />"));var h=a("#popup_container").outerWidth();var g=a("#popup_container").outerWidth();a("#popup_container").css({minWidth:p>0?Math.max(h,p):h,maxWidth:p>0?Math.max(g,p):g});a("<div id = 'popup_close' class = 'close_mouseout' style='position: absolute;top: 0;right: 7px;width: 25px;height: 30px'>").appendTo("#popup_header").bind("mouseover",function(){a("#popup_close").removeClass("close_mouseout");
a("#popup_close").addClass("close_mouseover")}).bind("mouseout",function(){a("#popup_close").removeClass("close_mouseover");a("#popup_close").removeClass("close_click");a("#popup_close").addClass("close_mouseout")}).bind("mousedown",function(){a("#popup_close").removeClass("close_mouseover");a("#popup_close").addClass("close_click")}).bind("click",function(){FR.Msg._hide();if(i){i(null)}});j=p==-1?j:j.replace(/([\u4E00-\u9FA5\uf900-\ufa2d])/g,"aa");var m=j.length;switch(d){case"alert":a("#popup_container").css({minWidth:"400px",maxWidth:"400px",width:"400px"});
a("#popup_message").css({width:"380px",wordBreak:"break-all",fontSize:"14px",fontWeight:"bold"});var q=a("#popup_message").height();var v=q+87;v=v>150?v:150;a("#popup_container").css({height:v});a("#popup_header").css({width:"400px"});a("#popup_content").css({top:"40px",left:"10px",background:"none",padding:"0px",fontSize:"14px",textAlign:"left"});var c=new FR.createWidget({type:"quickbutton",style:this.style,text:FR.i18nText("OK"),width:60,height:28,handler:function(){FR.Msg._hide();i(true)}});var u=c.element.appendTo("#popup_container").css({position:"absolute",right:"20px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});
u.focus();u.keydown(function(x){if(x.keyCode===13||x.keyCode===27){u.trigger("click")}});break;case"confirm":if(j){if(m<7){a("#popup_container").css({minWidth:"233px",maxWidth:"233px",width:"233px",height:"149px"});a("#popup_content").css({left:"32px",width:"100px"});a("#popup_header").css({width:"233px"});a("#popup_message").css({width:"100px"})}else{if(m>6&&m<11){a("#popup_container").css({minWidth:"233px",maxWidth:"233px",width:"233px",height:"149px"});a("#popup_content").css({left:"33px",width:"98px",backgroundPosition:"23px 31px"});
a("#popup_header").css({width:"233px"});a("#popup_message").css({width:"98px"})}else{var n=m*17/2+16;p=p>233?p:233;var b=(n+100)>p?n+100:p;a("#popup_container").css({minWidth:b+"px",maxWidth:b+"px",width:b+"px",height:"169px"});a("#popup_content").css({left:"15.5px",width:n+"px",backgroundPosition:"23px 31px"});a("#popup_header").css({width:b+"px"});a("#popup_message").css({width:n+"px"})}}}else{a("#popup_container").css({minWidth:"233px",maxWidth:"233px",width:"233px",height:"149px"});a("#popup_header").css({width:"233px"});
a("#popup_content").css({left:"46px",top:"45px"})}var k=document.getElementById("popup_container").offsetWidth;var r=(k-140)/2-1;var c=new FR.createWidget({type:"quickbutton",style:this.style,text:FR.i18nText("OK"),width:60,height:28,handler:function(){FR.Msg._hide();i(true)}});var u=c.element.appendTo("#popup_container").css({position:"absolute",left:r+"px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});var f=new FR.createWidget({type:"quickbutton",style:"gray",text:FR.i18nText("Cancel"),width:60,height:28,handler:function(){FR.Msg._hide();
i(false)}});var o=f.element.appendTo("#popup_container").css({position:"absolute",right:r+"px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});break;case"prompt":a("#popup_content").append('<input type="text" size="21" id="popup_prompt" >');if(j){p=p>233?p:233;var n=(m*14+15)>p-100?(m*14+15):p-100;var b=n+100;a("#popup_container").css({minWidth:b,maxWidth:b,width:b});a("#popup_header").css({width:b});a("#popup_content").css({left:"50px",top:"45px",width:n,height:"59px",padding:"0"});
a("#popup_message").css({fontSize:"14px",width:n,textAlign:"left"})}else{a("#popup_container").css({minWidth:"233px",maxWidth:"233px",width:"233px"});a("#popup_header").css({width:"233px"});a("#popup_content").css({left:"50px",top:"52px",width:"130px",height:"59px",padding:"0"});a("#popup_message").css({width:"130px"})}var k=document.getElementById("popup_container").offsetWidth;var r=(k-140)/2-1;var c=new FR.createWidget({type:"quickbutton",style:this.style,text:FR.i18nText("OK"),width:60,height:28,handler:function(){var e=a("#popup_prompt").val();
FR.Msg._hide();if(i){i(e)}}});var u=c.element.appendTo("#popup_container").css({position:"absolute",left:r+"px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});var f=new FR.createWidget({type:"quickbutton",style:"gray",text:FR.i18nText("Cancel"),width:60,height:28,handler:function(){FR.Msg._hide();if(i){i(null)}}});var o=f.element.appendTo("#popup_container").css({position:"absolute",right:r+"px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});
a("#popup_prompt").width(a("#popup_message").width());if(s){a("#popup_prompt").val(s)}a("#popup_prompt").focus().select();break}this._reposition();this._maintainPosition(true);if(this.draggable){try{a("#popup_container").draggable({handle:a("#popup_title"),onStopDrag:function(){if(a("#popup_container").offset().top<0){a("#popup_container").css({top:"0px"})}if(a("#popup_container").offset().left<0){a("#popup_container").css({left:"0px"})}}});a("#popup_title").css({cursor:"move"})}catch(t){}}},_hide:function(){a("#popup_container").remove();
this._overlay("hide");this._maintainPosition(false)},_overlay:function(b){switch(b){case"show":this._overlay("hide");a("BODY").append('<div id="popup_overlay"></div>');a("#popup_overlay").css({position:"absolute",zIndex:99998,top:"0px",left:"0px",width:"100%",height:a(document).height(),background:this.overlayColor,opacity:this.overlayOpacity});break;case"hide":a("#popup_overlay").remove();break}},_reposition:function(){var c=(FR.isMobileBrowser()&&!FR.isMobileBrowserNoZoom())?FR.MobileTools.getScreenHeight():a(window.document).height();
c=(c-a("#popup_container").outerHeight())/2+this.verticalOffset;c=c*this.verticalOffset;var b=(FR.isMobileBrowser()&&!FR.isMobileBrowserNoZoom())?FR.MobileTools.getScreenWidth():a(window.document).width();b=(b-a("#popup_container").outerWidth())/2+this.horizontalOffset;b=b*this.horizontalOffset;if(c<0){c=0}if(b<0){b=0}if(a.browser.msie){c=c+a(window).scrollTop()}a("#popup_container").css({top:c+"px",left:b+"px"});a("#popup_overlay").height(a(document).height())},_maintainPosition:function(b){if(this.repositionOnResize){switch(b){case true:a(window).bind("resize",function(){FR.Msg._reposition()
});break;case false:a(window).unbind("resize");break}}}}}()})})(jQuery);

==> fr-server-7.1.12.jar: com/fr/web/core/js/jquery.message.js <==
(function(a){a.extend(FR,{Msg:function(){return{verticalOffset:0.77,horizontalOffset:1,repositionOnResize:true,overlayOpacity:0.01,overlayColor:"#FFF",draggable:true,okButton:FR.i18nText("OK"),cancelButton:FR.i18nText("Cancel"),dialogClass:null,style:null,textSpace:FR.i18nText("FR-Widget_Message_Letter_Space")+"px",msgStyle:function(){var b=this.style;var c="blue";a.each(["green","blue"],function(d,e){if(b&&e==b.toLowerCase()){c=b.toLowerCase()}});this.style=c},alert:function(c,b,d){FR.Keys.enable(false);
if(!c){c="Alert"}this._show(c,b,null,"alert",function(e){FR.Keys.enable(true);if(a.isFunction(d)){d(e)}},-1);if(typeof d=="number"&&d>0){setTimeout(function(){FR.Msg._hide()},d)}},confirm:function(c,b,e,d){FR.Keys.enable(false);if(!c){c="Confirm"}this._show(c,b,null,"confirm",function(f){FR.Keys.enable(true);if(e){e(f)}},d?d:-1)},prompt:function(d,b,c,f,e){FR.Keys.enable(false);if(!d){d="Prompt"}this._show(d,b,c,"prompt",function(g){FR.Keys.enable(true);if(f){f(g)}},e?e:-1)},toast:function(e){var d=-300;
if(a.browser.msie&&parseInt(a.browser.version)<8){d=-370}var c=a("body").children("div.toast");if(c.length===0){var f=60;if(a.browser.msie&&parseInt(a.browser.version)<=6){f+=a("body")[0].scrollTop}c=a("<div/>").addClass("toast").css({right:d,top:f}).appendTo("body")}c.text(e);var b=a("body").children("div.toastIcon");if(b.length===0){b=a("<div/>").addClass("toastIcon").css({right:0,top:c.css("top"),"z-index":c.css("z-index")+1}).appendTo("body");new FR.IconButton({width:b.css("width"),height:b.css("height"),imgsrc:"fr_show_toast",renderEl:a("<div/>").appendTo(b),handler:function(){c.animate({right:-4},"slow");
setTimeout(function(){c.animate({right:d},"slow")},5000)}})}b.hide();c.animate({right:-15},"slow");(function(){c.animate({right:d},"slow",function(){b.show();b.fadeOut(5000)})}).defer(5000)},_show:function(w,j,s,d,i,p){this.msgStyle();this._hide();this._overlay("show");a("BODY").append('<div id="popup_container"><div id="popup_header" ><h1 id="popup_title"></h1></div><div id="popup_content"><div id="popup_message"></div></div></div>');if(this.dialogClass){a("#popup_container").addClass(this.dialogClass)
}var l=(a.browser.msie)?"absolute":"fixed";a("#popup_container").css({position:l,zIndex:99999,padding:0,margin:0,top:0,left:0});a("#popup_title").html(w);a("#popup_content").addClass(d);a("#popup_message").text(j);a("#popup_message").html(a("#popup_message").text().replace(/\n/g,"<br />"));var h=a("#popup_container").outerWidth();var g=a("#popup_container").outerWidth();a("#popup_container").css({minWidth:p>0?Math.max(h,p):h,maxWidth:p>0?Math.max(g,p):g});a("<div id = 'popup_close' class = 'close_mouseout' style='position: absolute;top: 0;right: 7px;width: 25px;height: 30px'>").appendTo("#popup_header").bind("mouseover",function(){a("#popup_close").removeClass("close_mouseout");
a("#popup_close").addClass("close_mouseover")}).bind("mouseout",function(){a("#popup_close").removeClass("close_mouseover");a("#popup_close").removeClass("close_click");a("#popup_close").addClass("close_mouseout")}).bind("mousedown",function(){a("#popup_close").removeClass("close_mouseover");a("#popup_close").addClass("close_click")}).bind("click",function(){FR.Msg._hide();if(i){i(null)}});j=p==-1?j:j.replace(/([\u4E00-\u9FA5\uf900-\ufa2d])/g,"aa");var m=j?j.length:0;switch(d){case"alert":a("#popup_container").css({minWidth:"400px",maxWidth:"400px",width:"400px"});
a("#popup_message").css({width:"380px",wordBreak:"break-all",fontSize:"14px",fontWeight:"bold"});var q=a("#popup_message").height();var v=q+87;v=v>150?v:150;a("#popup_container").css({height:v});a("#popup_header").css({width:"400px"});a("#popup_content").css({top:"40px",left:"10px",background:"none",padding:"0px",fontSize:"14px",textAlign:"left"});var c=new FR.createWidget({type:"quickbutton",style:this.style,text:FR.i18nText("OK"),width:60,height:28,handler:function(){FR.Msg._hide();i(true)}});var u=c.element.appendTo("#popup_container").css({position:"absolute",right:"20px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});
u.focus();u.keydown(function(x){if(x.keyCode===13||x.keyCode===27){u.trigger("click")}});break;case"confirm":if(j){if(m<7){a("#popup_container").css({minWidth:"233px",maxWidth:"233px",width:"233px",height:"149px"});a("#popup_content").css({left:"32px",width:"100px"});a("#popup_header").css({width:"233px"});a("#popup_message").css({width:"100px"})}else{if(m>6&&m<11){a("#popup_container").css({minWidth:"233px",maxWidth:"233px",width:"233px",height:"149px"});a("#popup_content").css({left:"33px",width:"98px",backgroundPosition:"23px 31px"});
a("#popup_header").css({width:"233px"});a("#popup_message").css({width:"98px"})}else{var n=m*17/2+16;p=p>233?p:233;var b=(n+100)>p?n+100:p;a("#popup_container").css({minWidth:b+"px",maxWidth:b+"px",width:b+"px",height:"169px"});a("#popup_content").css({left:"15.5px",width:n+"px",backgroundPosition:"23px 31px"});a("#popup_header").css({width:b+"px"});a("#popup_message").css({width:n+"px"})}}}else{a("#popup_container").css({minWidth:"233px",maxWidth:"233px",width:"233px",height:"149px"});a("#popup_header").css({width:"233px"});
a("#popup_content").css({left:"46px",top:"45px"})}var k=document.getElementById("popup_container").offsetWidth;var r=(k-140)/2-1;var c=new FR.createWidget({type:"quickbutton",style:this.style,text:FR.i18nText("OK"),width:60,height:28,handler:function(){FR.Msg._hide();i(true)}});var u=c.element.appendTo("#popup_container").css({position:"absolute",left:r+"px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});var f=new FR.createWidget({type:"quickbutton",style:"gray",text:FR.i18nText("Cancel"),width:60,height:28,handler:function(){FR.Msg._hide();
i(false)}});var o=f.element.appendTo("#popup_container").css({position:"absolute",right:r+"px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});break;case"prompt":a("#popup_content").append('<input type="text" size="21" id="popup_prompt" >');if(j){p=p>233?p:233;var n=(m*14+15)>p-100?(m*14+15):p-100;var b=n+100;a("#popup_container").css({minWidth:b,maxWidth:b,width:b});a("#popup_header").css({width:b});a("#popup_content").css({left:"50px",top:"45px",width:n,height:"59px",padding:"0"});
a("#popup_message").css({fontSize:"14px",width:n,textAlign:"left"})}else{a("#popup_container").css({minWidth:"233px",maxWidth:"233px",width:"233px"});a("#popup_header").css({width:"233px"});a("#popup_content").css({left:"50px",top:"52px",width:"130px",height:"59px",padding:"0"});a("#popup_message").css({width:"130px"})}var k=document.getElementById("popup_container").offsetWidth;var r=(k-140)/2-1;var c=new FR.createWidget({type:"quickbutton",style:this.style,text:FR.i18nText("OK"),width:60,height:28,handler:function(){var e=a("#popup_prompt").val();
FR.Msg._hide();if(i){i(e)}}});var u=c.element.appendTo("#popup_container").css({position:"absolute",left:r+"px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});var f=new FR.createWidget({type:"quickbutton",style:"gray",text:FR.i18nText("Cancel"),width:60,height:28,handler:function(){FR.Msg._hide();if(i){i(null)}}});var o=f.element.appendTo("#popup_container").css({position:"absolute",right:r+"px",bottom:"8px",letterSpacing:FR.Msg.textSpace,textIndent:a.browser.msie&&document.documentMode<8?0:FR.Msg.textSpace});
a("#popup_prompt").width(a("#popup_message").width());if(s){a("#popup_prompt").val(s)}a("#popup_prompt").focus().select();break}this._reposition();this._maintainPosition(true);if(this.draggable){try{a("#popup_container").draggable({handle:a("#popup_title"),onStopDrag:function(){if(a("#popup_container").offset().top<0){a("#popup_container").css({top:"0px"})}if(a("#popup_container").offset().left<0){a("#popup_container").css({left:"0px"})}}});a("#popup_title").css({cursor:"move"})}catch(t){}}},_hide:function(){a("#popup_container").remove();
this._overlay("hide");this._maintainPosition(false)},_overlay:function(b){switch(b){case"show":this._overlay("hide");a("BODY").append('<div id="popup_overlay"></div>');a("#popup_overlay").css({position:"absolute",zIndex:99998,top:"0px",left:"0px",width:"100%",height:a(document).height(),background:this.overlayColor,opacity:this.overlayOpacity});break;case"hide":a("#popup_overlay").remove();break}},_reposition:function(){var c=(FR.isMobileBrowser()&&!FR.isMobileBrowserNoZoom())?FR.MobileTools.getScreenHeight():a(window.document).height();
c=(c-a("#popup_container").outerHeight())/2+this.verticalOffset;c=c*this.verticalOffset;var b=(FR.isMobileBrowser()&&!FR.isMobileBrowserNoZoom())?FR.MobileTools.getScreenWidth():a(window.document).width();b=(b-a("#popup_container").outerWidth())/2+this.horizontalOffset;b=b*this.horizontalOffset;if(c<0){c=0}if(b<0){b=0}if(a.browser.msie){c=c+a(window).scrollTop()}a("#popup_container").css({top:c+"px",left:b+"px"});a("#popup_overlay").height(a(document).height())},_maintainPosition:function(b){if(this.repositionOnResize){switch(b){case true:a(window).bind("resize",function(){FR.Msg._reposition()
});break;case false:a(window).unbind("resize");break}}}}}()})})(jQuery);
